@@ -17,15 +17,19 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
+
 #include "fileselectdlg.h"
 
+#include <QButtonGroup>
 #include <QMenu>
-#include <QTextCodec>
-#include <klocalizedstring.h>
-#include <kio/global.h>
-#include <kmessagebox.h>
-#include <kstandardguiitem.h>
 #include <QPushButton>
+#include <QTextCodec>
+
+#include <KIO/Global>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KStandardGuiItem>
+
 #include <interfaces/torrentfileinterface.h>
 #include <interfaces/torrentinterface.h>
 #include <util/functions.h>
@@ -48,29 +52,29 @@ namespace kt
 
     FileSelectDlg::FileSelectDlg(kt::QueueManager* qman, kt::GroupManager* gman, const QString& group_hint, QWidget* parent)
         : QDialog(parent)
-        , tc(0)
-        , model(0)
+        , tc(nullptr)
+        , model(nullptr)
         , qman(qman)
         , gman(gman)
-        , start(0)
-        , skip_check(0)
-        , initial_group(0)
+        , start(nullptr)
+        , skip_check(nullptr)
+        , initial_group(nullptr)
         , show_file_tree(true)
         , already_downloaded(0)
     {
         setupUi(this);
-        connect(buttonBox,SIGNAL(accepted()),this,SLOT(accept()));
-        connect(buttonBox,SIGNAL(rejected()),this,SLOT(reject()));
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &FileSelectDlg::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &FileSelectDlg::reject);
 
         m_file_view->setAlternatingRowColors(true);
         filter_model = new TreeFilterModel(this);
         m_file_view->setModel(filter_model);
         //root = 0;
-        connect(m_select_all, SIGNAL(clicked()), this, SLOT(selectAll()));
-        connect(m_select_none, SIGNAL(clicked()), this, SLOT(selectNone()));
-        connect(m_invert_selection, SIGNAL(clicked()), this, SLOT(invertSelection()));
-        connect(m_collapse_all, SIGNAL(clicked()), m_file_view, SLOT(collapseAll()));
-        connect(m_expand_all, SIGNAL(clicked()), m_file_view, SLOT(expandAll()));
+        connect(m_select_all, &QPushButton::clicked, this, &FileSelectDlg::selectAll);
+        connect(m_select_none, &QPushButton::clicked, this, &FileSelectDlg::selectNone);
+        connect(m_invert_selection, &QPushButton::clicked, this, &FileSelectDlg::invertSelection);
+        connect(m_collapse_all, &QPushButton::clicked, m_file_view, &QTreeView::collapseAll);
+        connect(m_expand_all, &QPushButton::clicked, m_file_view, &QTreeView::expandAll);
 
         m_downloadLocation->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
         m_completedLocation->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
@@ -83,7 +87,7 @@ namespace kt
         encodings = QTextCodec::availableMibs();
         foreach (int mib, encodings)
         {
-            m_encoding->addItem(QTextCodec::codecForMib(mib)->name());
+            m_encoding->addItem(QString::fromUtf8(QTextCodec::codecForMib(mib)->name()));
         }
 
         if (!group_hint.isNull())
@@ -92,10 +96,10 @@ namespace kt
         QButtonGroup* bg = new QButtonGroup(this);
         m_tree->setIcon(QIcon::fromTheme(QStringLiteral("view-list-tree")));
         m_tree->setToolTip(i18n("Show a file tree"));
-        connect(m_tree, SIGNAL(clicked(bool)), this, SLOT(fileTree(bool)));
+        connect(m_tree, &QToolButton::clicked, this, &FileSelectDlg::fileTree);
         m_list->setIcon(QIcon::fromTheme(QStringLiteral("view-list-text")));
         m_list->setToolTip(i18n("Show a file list"));
-        connect(m_list, SIGNAL(clicked(bool)), this, SLOT(fileList(bool)));
+        connect(m_list, &QToolButton::clicked, this, &FileSelectDlg::fileList);
         m_tree->setCheckable(true);
         m_list->setCheckable(true);
         bg->addButton(m_tree);
@@ -104,12 +108,12 @@ namespace kt
 
         m_filter->setClearButtonEnabled(true);
         m_filter->setPlaceholderText(i18n("Filter"));
-        connect(m_filter, SIGNAL(textChanged(QString)), this, SLOT(setFilter(QString)));
+        connect(m_filter, &QLineEdit::textChanged, this, &FileSelectDlg::setFilter);
 
         m_moveCompleted->setCheckState(Settings::useCompletedDir()?Qt::Checked:Qt::Unchecked);
 
         m_completedLocation->setEnabled(Settings::useCompletedDir());
-        connect(m_moveCompleted, SIGNAL(toggled(bool)), this, SLOT(moveCompletedToggled(bool)));
+        connect(m_moveCompleted, &QCheckBox::toggled, this, &FileSelectDlg::moveCompletedToggled);
     }
 
     FileSelectDlg::~FileSelectDlg()
@@ -126,9 +130,9 @@ namespace kt
         this->skip_check = skip_check;
 
         int idx = encodings.indexOf(tc->getTextCodec()->mibEnum());
-        Out(SYS_GEN | LOG_DEBUG) << "Codec: " << QString(tc->getTextCodec()->name()) << " " << idx << endl;
+        Out(SYS_GEN | LOG_DEBUG) << "Codec: " << QString::fromLatin1(tc->getTextCodec()->name()) << " " << idx << endl;
         m_encoding->setCurrentIndex(idx);
-        connect(m_encoding, SIGNAL(currentIndexChanged(QString)), this, SLOT(onCodecChanged(QString)));
+        connect(m_encoding, static_cast<void (KComboBox::*)(const QString &)>(&KComboBox::currentIndexChanged), this, &FileSelectDlg::onCodecChanged);
 
 
         for (Uint32 i = 0; i < tc->getNumFiles(); i++)
@@ -145,8 +149,8 @@ namespace kt
 
         model->setFileNamesEditable(true);
 
-        connect(model, SIGNAL(checkStateChanged()), this, SLOT(updateSizeLabels()));
-        connect(m_downloadLocation, SIGNAL(textChanged(QString)), this, SLOT(downloadLocationChanged(QString)));
+        connect(model, &TorrentFileModel::checkStateChanged, this, &FileSelectDlg::updateSizeLabels);
+        connect(m_downloadLocation, &KUrlRequester::textChanged, this, &FileSelectDlg::downloadLocationChanged);
         filter_model->setSourceModel(model);
         filter_model->setSortRole(Qt::UserRole);
         m_file_view->setSortingEnabled(true);
@@ -180,14 +184,20 @@ namespace kt
         QStringList pe_ex;
 
         QString cn = m_completedLocation->url().toLocalFile();
-        if (!cn.endsWith('/')) cn += '/';
+        if (!cn.endsWith(QLatin1Char('/'))) cn += QLatin1Char('/');
         if (m_moveCompleted->isChecked() && !cn.isEmpty())
-            move_on_completion_location_history.insert(cn);
+        {
+            move_on_completion_location_history.removeOne(cn);
+            move_on_completion_location_history.prepend(cn);
+        }
 
         QString dn = m_downloadLocation->url().toLocalFile();
-        if (!dn.endsWith('/')) dn += '/';
+        if (!dn.endsWith(QLatin1Char('/'))) dn += QLatin1Char('/');
         if (!dn.isEmpty())
-            download_location_history.insert(dn);
+        {
+            download_location_history.removeOne(dn);
+            download_location_history.prepend(dn);
+        }
 
 
         QString tld = tc->getUserModifiedFileName();
@@ -455,7 +465,7 @@ namespace kt
         }
 
         m_cmbGroups->addItems(grps);
-        connect(m_cmbGroups, SIGNAL(activated(int)), this, SLOT(groupActivated(int)));
+        connect(m_cmbGroups, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &FileSelectDlg::groupActivated);
 
         if (selected > 0 && initial_group)
         {
@@ -546,7 +556,7 @@ namespace kt
         {
             already_downloaded = 0;
             bt::Uint32 found = 0;
-            QString path = m_downloadLocation->url().path() + '/' + tc->getDisplayName() + '/';
+            QString path = m_downloadLocation->url().path() + QLatin1Char('/') + tc->getDisplayName() + QLatin1Char('/');
             for (bt::Uint32 i = 0; i < tc->getNumFiles(); i++)
             {
                 const bt::TorrentFileInterface& file = tc->getTorrentFile(i);
@@ -573,7 +583,7 @@ namespace kt
         }
         else
         {
-            QString path = m_downloadLocation->url().path() + '/' + tc->getDisplayName();
+            QString path = m_downloadLocation->url().path() + QLatin1Char('/') + tc->getDisplayName();
             if (!bt::Exists(path))
             {
                 m_existing_found->setText(i18n("Existing file: <b>No</b>"));
@@ -612,10 +622,12 @@ namespace kt
         show_file_tree = g.readEntry("show_file_tree", true);
         m_tree->setChecked(show_file_tree);
         m_list->setChecked(!show_file_tree);
-        QStringList tmp = g.readEntry("download_location_history", QStringList());
-        download_location_history = QSet<QString>::fromList(tmp);
-        tmp = g.readEntry("move_on_completion_location_history", QStringList());
-        move_on_completion_location_history = QSet<QString>::fromList(tmp);
+        download_location_history = g.readEntry("download_location_history", QStringList());
+        for (int i=0; i<download_location_history.count(); i++)
+            if (download_location_history.at(i).endsWith(QLatin1String("//"))) download_location_history[i].chop(1);
+        download_location_history.removeDuplicates();
+        move_on_completion_location_history = g.readEntry("move_on_completion_location_history", QStringList());
+        move_on_completion_location_history.removeDuplicates();
 
         if (download_location_history.count())
         {
@@ -647,12 +659,12 @@ namespace kt
         KConfigGroup g = cfg->group("FileSelectDlg");
         g.writeEntry("size", size());
         g.writeEntry("show_file_tree", show_file_tree);
-        g.writeEntry("download_location_history", download_location_history.toList());
-        g.writeEntry("move_on_completion_location_history", move_on_completion_location_history.toList());
+        g.writeEntry("download_location_history", download_location_history);
+        g.writeEntry("move_on_completion_location_history", move_on_completion_location_history);
         g.writeEntry("file_view", m_file_view->header()->saveState());
     }
 
-    QMenu* FileSelectDlg::createHistoryMenu(const QSet<QString> & urls, const char* slot)
+    QMenu* FileSelectDlg::createHistoryMenu(const QStringList & urls, const char* slot)
     {
         QMenu* m = new QMenu(this);
         foreach (const QString& url, urls)
@@ -720,7 +732,7 @@ namespace kt
             model = new TorrentFileListModel(tc, TorrentFileTreeModel::DELETE_FILES, this);
 
         model->setFileNamesEditable(true);
-        connect(model, SIGNAL(checkStateChanged()), this, SLOT(updateSizeLabels()));
+        connect(model, &TorrentFileModel::checkStateChanged, this, &FileSelectDlg::updateSizeLabels);
 
         filter_model->setSourceModel(model);
         m_file_view->header()->restoreState(hs);
