@@ -18,6 +18,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "grouppolicydlg.h"
 #include <groups/group.h>
 
@@ -28,8 +29,8 @@ namespace kt
         : QDialog(parent), group(group)
     {
         setupUi(this);
-        connect(buttonBox,SIGNAL(accepted()),this,SLOT(accept()));
-        connect(buttonBox,SIGNAL(rejected()),this,SLOT(reject()));
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &GroupPolicyDlg::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &GroupPolicyDlg::reject);
         setWindowTitle(i18n("Policy for the %1 group", group->groupName()));
 
         const Group::Policy& p = group->groupPolicy();
