@@ -17,11 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef IPFILTERWIDGET_H
 #define IPFILTERWIDGET_H
 
 #include "ui_ipfilterwidget.h"
-#include <KDialog>
+#include <QDialog>
 
 namespace kt
 {
@@ -32,12 +33,12 @@ namespace kt
     * @brief Integrated IPFilter GUI class.
     * Used to show, add and remove banned peers from blacklist.
     */
-    class IPFilterWidget: public KDialog, public Ui_IPFilterWidget
+    class IPFilterWidget: public QDialog, public Ui_IPFilterWidget
     {
         Q_OBJECT
     public:
         IPFilterWidget(QWidget* parent);
-        virtual ~IPFilterWidget();
+        ~IPFilterWidget();
 
         /// Register the filter list
         static void registerFilterList();
@@ -47,12 +48,12 @@ namespace kt
 
 
     public slots:
-        virtual void save();
-        virtual void open();
-        virtual void clear();
-        virtual void remove();
-        virtual void add();
-        virtual void accept();
+        void save();
+        void open();
+        void clear();
+        void remove();
+        void add();
+        void accept();
 
     private:
         void setupConnections();
