@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-
 #ifndef KT_DBUSTORRENTFILESTREAM_H
 #define KT_DBUSTORRENTFILESTREAM_H
 
@@ -39,7 +38,7 @@ namespace kt
         Q_CLASSINFO("D-Bus Interface", "org.ktorrent.torrentfilestream")
     public:
         DBusTorrentFileStream(bt::Uint32 file_index, DBusTorrent* tor);
-        virtual ~DBusTorrentFileStream();
+        ~DBusTorrentFileStream();
 
         /// Was the stream created properly ?
         bool ok() const {return !stream.isNull();}
