@@ -18,11 +18,15 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <kmimetype.h>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
-#include <kzip.h>
-#include <kio/jobuidelegate.h>
+
+#include <QMimeDatabase>
+#include <QMimeType>
+
+#include <KIO/JobUiDelegate>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KZip>
+
 #include <util/log.h>
 #include <util/functions.h>
 #include <util/fileops.h>
@@ -40,7 +44,7 @@ namespace kt
 {
 
     DownloadAndConvertJob::DownloadAndConvertJob(const QUrl& url, Mode mode)
-        : url(url), unzip(false), convert_dlg(0), mode(mode)
+        : url(url), unzip(false), convert_dlg(nullptr), mode(mode)
     {
     }
 
@@ -51,12 +55,12 @@ namespace kt
 
     void DownloadAndConvertJob::start()
     {
-        QString temp = kt::DataDir() + "tmp-" + url.fileName();
+        QString temp = kt::DataDir() + QStringLiteral("tmp-") + url.fileName();
         if (bt::Exists(temp))
             bt::Delete(temp, true);
 
-        active_job = KIO::file_copy(url, temp, -1, KIO::Overwrite);
-        connect(active_job, SIGNAL(result(KJob*)), this, SLOT(downloadFileFinished(KJob*)));
+        active_job = KIO::file_copy(url, QUrl::fromLocalFile(temp), -1, KIO::Overwrite);
+        connect(active_job, &KJob::result, this, &DownloadAndConvertJob::downloadFileFinished);
     }
 
     void DownloadAndConvertJob::kill(KJob::KillVerbosity)
@@ -69,13 +73,13 @@ namespace kt
 
     void DownloadAndConvertJob::convert(KJob* j)
     {
-        active_job = 0;
+        active_job = nullptr;
         if (j->error())
         {
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
             if (mode == Verbose)
             {
-                ((KIO::Job*)j)->ui()->showErrorMessage();
+                j->uiDelegate()->showErrorMessage();
             }
             else
             {
@@ -89,15 +93,32 @@ namespace kt
             convert();
     }
 
+    static bool isBinaryData(const QString &fileName)
+    {
+        QFile file(fileName);
+        if (!file.open(QIODevice::ReadOnly)) {
+            return false;    // err, whatever
+        }
+        // Check the first 32 bytes (see shared-mime spec)
+        const QByteArray data = file.read(32);
+        const char *p = data.data();
+        for (int i = 0; i < data.size(); ++i) {
+            if ((unsigned char)(p[i]) < 32 && p[i] != 9 && p[i] != 10 && p[i] != 13) { // ASCII control character
+                return true;
+            }
+        }
+        return false;
+    }
+
     void DownloadAndConvertJob::downloadFileFinished(KJob* j)
     {
-        active_job = 0;
+        active_job = nullptr;
         if (j->error())
         {
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
             if (mode == Verbose)
             {
-                ((KIO::Job*)j)->ui()->showErrorMessage();
+                j->uiDelegate()->showErrorMessage();
             }
             else
             {
@@ -110,43 +131,44 @@ namespace kt
             return;
         }
 
-        QString temp = kt::DataDir() + "tmp-" + url.fileName();
+        QString temp = kt::DataDir() + QStringLiteral("tmp-") + url.fileName();
 
         //now determine if it's ZIP or TXT file
-        KMimeType::Ptr ptr = KMimeType::findByFileContent(temp);
-        Out(SYS_IPF|LOG_NOTICE) << "Mimetype: " << ptr->name() << endl;
-        if(ptr->name() == "application/zip")
+        QMimeDatabase db;
+        QMimeType ptr = db.mimeTypeForFile(temp, QMimeDatabase::MatchContent);
+        Out(SYS_IPF|LOG_NOTICE) << "Mimetype: " << ptr.name() << endl;
+        if(ptr.name() == QStringLiteral("application/zip"))
         {
-            active_job = KIO::file_move(temp, QString(kt::DataDir() + QLatin1String("level1.zip")), -1, KIO::HideProgressInfo | KIO::Overwrite);
-            connect(active_job, SIGNAL(result(KJob*)), this, SLOT(extract(KJob*)));
+            active_job = KIO::file_move(QUrl::fromLocalFile(temp), QUrl::fromLocalFile(QString(kt::DataDir() + QLatin1String("level1.zip"))), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            connect(active_job, &KJob::result, this, &DownloadAndConvertJob::extract);
         }
-        else if(ptr->name() == "application/x-7z-compressed")
+        else if(ptr.name() == QStringLiteral("application/x-7z-compressed"))
         {
-            QString msg = i18n("7z files are not supported", url.prettyUrl());
+            QString msg = i18n("7z files are not supported", url.toDisplayString());
             if (mode == Verbose)
-                KMessageBox::error(0, msg);
+                KMessageBox::error(nullptr, msg);
             else
                 notification(msg);
             
             setError(UNZIP_FAILED);
             emitResult();
         }
-        else if(ptr->name() == "application/gzip" || ptr->name() == "application/x-bzip")
+        else if(ptr.name() == QStringLiteral("application/gzip") || ptr.name() == QStringLiteral("application/x-bzip"))
         {
-            active_job = new bt::DecompressFileJob(temp, QString(kt::DataDir() + "level1.txt"));
-            connect(active_job, SIGNAL(result(KJob*)), this, SLOT(convert(KJob*)));
+            active_job = new bt::DecompressFileJob(temp, kt::DataDir() + QStringLiteral("level1.txt"));
+            connect(active_job, &KJob::result, this, static_cast<void (DownloadAndConvertJob::*)(KJob*)>(&DownloadAndConvertJob::convert));
             active_job->start();
         }
-        else if(!KMimeType::isBinaryData(temp) || ptr->name() == "text/plain")
+        else if(!isBinaryData(temp) || ptr.name() == QStringLiteral("text/plain"))
         {
-            active_job = KIO::file_move(temp, QString(kt::DataDir() + "level1.txt"), -1, KIO::HideProgressInfo | KIO::Overwrite);
-            connect(active_job, SIGNAL(result(KJob*)), this, SLOT(convert(KJob*)));
+            active_job = KIO::file_move(QUrl::fromLocalFile(temp), QUrl::fromLocalFile(kt::DataDir() + QStringLiteral("level1.txt")), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            connect(active_job, &KJob::result, this, static_cast<void (DownloadAndConvertJob::*)(KJob*)>(&DownloadAndConvertJob::convert));
         }
         else
         {
-            QString msg = i18n("Cannot determine file type of <b>%1</b>", url.prettyUrl());
+            QString msg = i18n("Cannot determine file type of <b>%1</b>", url.toDisplayString());
             if (mode == Verbose)
-                KMessageBox::error(0, msg);
+                KMessageBox::error(nullptr, msg);
             else
                 notification(msg);
 
@@ -157,13 +179,13 @@ namespace kt
 
     void DownloadAndConvertJob::extract(KJob* j)
     {
-        active_job = 0;
+        active_job = nullptr;
         if (j->error())
         {
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
             if (mode == Verbose)
             {
-                ((KIO::Job*)j)->ui()->showErrorMessage();
+                j->uiDelegate()->showErrorMessage();
             }
             else
             {
@@ -175,14 +197,14 @@ namespace kt
             return;
         }
 
-        QString zipfile = kt::DataDir() + "level1.zip";
+        QString zipfile = kt::DataDir() + QStringLiteral("level1.zip");
         KZip* zip = new KZip(zipfile);
         if (!zip->open(QIODevice::ReadOnly) || !zip->directory())
         {
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: cannot open zip file " << zipfile << endl;
             if (mode == Verbose)
             {
-                KMessageBox::error(0, i18n("Cannot open zip file %1.", zipfile));
+                KMessageBox::error(nullptr, i18n("Cannot open zip file %1.", zipfile));
             }
             else
             {
@@ -196,12 +218,12 @@ namespace kt
             return;
         }
 
-        QString destination = kt::DataDir() + "level1.txt";
+        QString destination = kt::DataDir() + QStringLiteral("level1.txt");
         QStringList entries = zip->directory()->entries();
         if(entries.count() >= 1)
         {
             active_job = new bt::ExtractFileJob(zip, entries.front(), destination);
-            connect(active_job, SIGNAL(result(KJob*)), this, SLOT(convert(KJob*)));
+            connect(active_job, &KJob::result, this, static_cast<void (DownloadAndConvertJob::*)(KJob*)>(&DownloadAndConvertJob::convert));
             unzip = true;
             active_job->start();
         }
@@ -210,7 +232,7 @@ namespace kt
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: no blocklist found in zipfile " << zipfile << endl;
             if (mode == Verbose)
             {
-                KMessageBox::error(0, i18n("Cannot find blocklist in zip file %1.", zipfile));
+                KMessageBox::error(nullptr, i18n("Cannot find blocklist in zip file %1.", zipfile));
             }
             else
             {
@@ -239,7 +261,7 @@ namespace kt
             Out(SYS_IPF | LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
             if (mode == Verbose)
             {
-                ((KIO::Job*)j)->ui()->showErrorMessage();
+                j->uiDelegate()->showErrorMessage();
             }
             else
             {
@@ -251,18 +273,18 @@ namespace kt
         }
         else
         {
-            convert_dlg = new ConvertDialog(0);
+            convert_dlg = new ConvertDialog(nullptr);
             if (mode == Verbose)
                 convert_dlg->show();
-            connect(convert_dlg, SIGNAL(accepted()), this, SLOT(convertAccepted()));
-            connect(convert_dlg, SIGNAL(rejected()), this, SLOT(convertRejected()));
+            connect(convert_dlg, &ConvertDialog::accepted, this, &DownloadAndConvertJob::convertAccepted);
+            connect(convert_dlg, &ConvertDialog::rejected, this, &DownloadAndConvertJob::convertRejected);
         }
     }
 
     void DownloadAndConvertJob::convertAccepted()
     {
         convert_dlg->deleteLater();
-        convert_dlg = 0;
+        convert_dlg = nullptr;
         cleanUpFiles();
         setError(0);
         emitResult();
@@ -271,15 +293,15 @@ namespace kt
     void DownloadAndConvertJob::convertRejected()
     {
         convert_dlg->deleteLater();
-        convert_dlg = 0;
+        convert_dlg = nullptr;
         // shit happened move back backup stuff
-        QString dat_file = kt::DataDir() + "level1.dat";
-        QString tmp_file = kt::DataDir() + "level1.dat.tmp";
+        QString dat_file = kt::DataDir() + QStringLiteral("level1.dat");
+        QString tmp_file = kt::DataDir() + QStringLiteral("level1.dat.tmp");
 
         if (bt::Exists(tmp_file))
         {
-            active_job = KIO::file_copy(tmp_file, dat_file, -1, KIO::HideProgressInfo | KIO::Overwrite);
-            connect(active_job, SIGNAL(result(KJob*)), this, SLOT(revertBackupFinished(KJob*)));
+            active_job = KIO::file_copy(QUrl::fromLocalFile(tmp_file), QUrl::fromLocalFile(dat_file), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            connect(active_job, &KJob::result, this, &DownloadAndConvertJob::revertBackupFinished);
         }
         else
         {
@@ -291,27 +313,27 @@ namespace kt
 
     void DownloadAndConvertJob::convert()
     {
-        if (bt::Exists(kt::DataDir() + "level1.dat"))
+        if (bt::Exists(kt::DataDir() + QStringLiteral("level1.dat")))
         {
             // make backup of data file, if stuff fails we can always go back
-            QString dat_file = kt::DataDir() + "level1.dat";
-            QString tmp_file = kt::DataDir() + "level1.dat.tmp";
+            QString dat_file = kt::DataDir() + QStringLiteral("level1.dat");
+            QString tmp_file = kt::DataDir() + QStringLiteral("level1.dat.tmp");
 
 
-            KIO::Job* job = KIO::file_copy(dat_file, tmp_file, -1, KIO::HideProgressInfo | KIO::Overwrite);
-            connect(job, SIGNAL(result(KJob*)), this, SLOT(makeBackupFinished(KJob*)));
+            KIO::Job* job = KIO::file_copy(QUrl::fromLocalFile(dat_file), QUrl::fromLocalFile(tmp_file), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            connect(job, &KIO::Job::result, this, &DownloadAndConvertJob::makeBackupFinished);
         }
         else
-            makeBackupFinished(0);
+            makeBackupFinished(nullptr);
     }
 
     void DownloadAndConvertJob::cleanUpFiles()
     {
         // cleanup temp files
-        cleanUp(kt::DataDir() + "level1.zip");
-        cleanUp(kt::DataDir() + "level1.txt");
-        cleanUp(kt::DataDir() + "level1.tmp");
-        cleanUp(kt::DataDir() + "level1.dat.tmp");
+        cleanUp(kt::DataDir() + QStringLiteral("level1.zip"));
+        cleanUp(kt::DataDir() + QStringLiteral("level1.txt"));
+        cleanUp(kt::DataDir() + QStringLiteral("level1.tmp"));
+        cleanUp(kt::DataDir() + QStringLiteral("level1.dat.tmp"));
     }
 
     void DownloadAndConvertJob::cleanUp(const QString& path)
