@@ -18,8 +18,10 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include <QComboBox>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+
 #include <util/log.h>
 #include "logflagsdelegate.h"
 
