@@ -18,10 +18,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <QMimeData>
+
+#include <QFileInfo>
 #include <QIcon>
-#include <kmimetype.h>
-#include <klocalizedstring.h>
+#include <QMimeData>
+
+#include <KLocalizedString>
+
 #include <util/log.h>
 #include <util/constants.h>
 #include <util/functions.h>
@@ -29,7 +32,6 @@
 #include <interfaces/torrentinterface.h>
 #include <interfaces/torrentfileinterface.h>
 #include <torrent/queuemanager.h>
-#include <QFileInfo>
 #include "mediamodel.h"
 
 
@@ -95,7 +97,7 @@ namespace kt
         case Qt::DisplayRole:
             return mf->name();
         case Qt::DecorationRole:
-            return QIcon::fromTheme(KMimeType::findByPath(mf->path())->iconName());
+            return QIcon::fromTheme(m_mimeDatabase.mimeTypeForFile(mf->path()).iconName());
         case Qt::UserRole: // user role is for finding out if a torrent is complete
             return mf->fullyAvailable();
         case Qt::UserRole + 1:
@@ -235,7 +237,7 @@ namespace kt
     QStringList MediaModel::mimeTypes() const
     {
         QStringList types;
-        types << "text/uri-list";
+        types << QStringLiteral("text/uri-list");
         return types;
     }
 
