@@ -17,14 +17,17 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "scanfolder.h"
 
 #include <QDir>
-#include <klocalizedstring.h>
-#include <KFileItem>
+
 #include <KConfigGroup>
-#include <kglobal.h>
-#include <kio/job.h>
+#include <KFileItem>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KIO/Job>
+
 #include <util/log.h>
 #include <util/functions.h>
 #include <util/fileops.h>
@@ -41,7 +44,7 @@ namespace kt
     ScanFolder::ScanFolder(ScanThread* scanner, const QUrl &dir, bool recursive)
         : scanner(scanner),
           scan_directory(dir),
-          watch(0),
+          watch(nullptr),
           recursive(recursive)
     {
         bt::Out(SYS_SNF | LOG_NOTICE) << "ScanFolder: scanning " << dir << endl;
@@ -52,12 +55,12 @@ namespace kt
         config.sync();
 
         watch = new KDirWatch(this);
-        connect(watch, SIGNAL(dirty(QString)), this, SLOT(scanDir(QString)));
-        connect(watch, SIGNAL(created(QString)), this, SLOT(scanDir(QString)));
+        connect(watch, &KDirWatch::dirty, this, &ScanFolder::scanDir);
+        connect(watch, &KDirWatch::created, this, &ScanFolder::scanDir);
 
         watch->addDir(dir.toLocalFile(), recursive ? KDirWatch::WatchSubDirs : KDirWatch::WatchDirOnly);
 
-        scanner->addDirectory(dir.toLocalFile(), recursive);
+        scanner->addDirectory(dir, recursive);
     }
 
 
@@ -79,7 +82,7 @@ namespace kt
             return;
 
         Out(SYS_SNF | LOG_NOTICE) << "Directory dirty: " << path << endl;
-        scanner->addDirectory(path, false);
+        scanner->addDirectory(QUrl::fromLocalFile(path), false);
     }
 
     void ScanFolder::setRecursive(bool rec)
