@@ -18,7 +18,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <kio/copyjob.h>
+
+#include <KIO/CopyJob>
 #include <util/fileops.h>
 #include <util/log.h>
 #include "opensearchdownloadjob.h"
@@ -28,7 +29,7 @@ using namespace bt;
 namespace kt
 {
 
-    OpenSearchDownloadJob::OpenSearchDownloadJob(const QUrl &url, const QString& dir) : url(url), dir(dir)
+    OpenSearchDownloadJob::OpenSearchDownloadJob(const QUrl &url, const QString& dir, ProxyHelper *proxy) : url(url), dir(dir), m_proxy(proxy)
     {
     }
 
@@ -41,7 +42,19 @@ namespace kt
     {
         // first try to download the html page
         KIO::StoredTransferJob* j = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
-        connect(j, SIGNAL(result(KJob*)), this, SLOT(getFinished(KJob*)));
+
+        KIO::MetaData metadata = j->metaData();
+        m_proxy->ApplyProxy(metadata);
+        j->setMetaData(metadata);
+
+        connect(j, &KIO::StoredTransferJob::result, this, &OpenSearchDownloadJob::getFinished);
+    }
+
+    void OpenSearchDownloadJob::startDefault()
+    {
+        // second try to access the xml file
+        url.setPath(QLatin1String("/opensearch.xml"));
+        start();
     }
 
     void OpenSearchDownloadJob::getFinished(KJob* j)
@@ -53,40 +66,42 @@ namespace kt
             return;
         }
 
-        QString str = QString(((KIO::StoredTransferJob*)j)->data());
+        QString str = QString::fromUtf8(((KIO::StoredTransferJob*)j)->data());
 
-        // try to find the link tags
-        QRegExp rx(QLatin1String("<link([^<>]*)"), Qt::CaseInsensitive);
-        int pos = 0;
+        if (url.path() != QStringLiteral("/opensearch.xml")) {
+            // try to find the link tags
+            QRegExp rx(QLatin1String("<link([^<>]*)"), Qt::CaseInsensitive);
+            int pos = 0;
 
-        while ((pos = rx.indexIn(str, pos)) != -1)
-        {
-            QString link_tag = rx.cap(1);
-            // exit when we find the description
-            if (checkLinkTagContent(link_tag))
-                return;
+            while ((pos = rx.indexIn(str, pos)) != -1)
+            {
+                QString link_tag = rx.cap(1);
+                // exit when we find the description
+                if (checkLinkTagContent(link_tag))
+                    return;
 
-            pos += rx.matchedLength();
+                pos += rx.matchedLength();
+            }
+        }
+        else {
+            if (str.contains(QStringLiteral("<OpenSearchDescription")) && str.contains(QStringLiteral("</OpenSearchDescription>")))
+            {
+                if (startXMLDownload(url))
+                    return;
+            }
+
+            setError(KIO::ERR_INTERNAL);
+            emitResult();
+            return;
         }
 
-
-        // no link tag found emit error
-        setError(KIO::ERR_INTERNAL);
-        emitResult();
+        // no link to openSearch xml found in html.
+        // make last attempt to access it by <protocol>://<domain>/opensearch.xml
+        startDefault();
     }
 
-    bool OpenSearchDownloadJob::checkLinkTagContent(const QString& content)
+    bool OpenSearchDownloadJob::startXMLDownload(const QUrl& url)
     {
-        if (htmlParam("type", content) != QLatin1String("application/opensearchdescription+xml"))
-            return false;
-
-        QString href = htmlParam("href", content);
-        if (href.isEmpty())
-            return false;
-
-        if (href.startsWith('/'))
-            href = url.scheme() + QLatin1String("://") + url.host() + href;
-
         if (!bt::Exists(dir))
         {
             try
@@ -100,11 +115,30 @@ namespace kt
         }
 
         // href is the opensearch description, so lets try to download it
-        KIO::Job* j = KIO::copy(QUrl(href), QUrl::fromLocalFile(dir + QLatin1String("opensearch.xml")), KIO::HideProgressInfo);
-        connect(j, SIGNAL(result(KJob*)), this, SLOT(xmlFileDownloadFinished(KJob*)));
+        KIO::Job* j = KIO::copy(url, QUrl::fromLocalFile(dir + QLatin1String("opensearch.xml")), KIO::HideProgressInfo);
+        connect(j, &KIO::Job::result, this, &OpenSearchDownloadJob::xmlFileDownloadFinished);
         return true;
     }
 
+    bool OpenSearchDownloadJob::checkLinkTagContent(const QString& content)
+    {
+        if (htmlParam(QStringLiteral("type"), content) != QLatin1String("application/opensearchdescription+xml"))
+            return false;
+
+        QString href = htmlParam(QStringLiteral("href"), content);
+        if (href.isEmpty())
+            return false;
+
+        if (href.startsWith(QLatin1String("//"))) { // href may point to other domain without protocol like "//not_here.com/search.xml"
+            href = url.scheme() + QLatin1Char(':') + href;
+        }
+        else if (href.startsWith(QLatin1Char('/'))) {
+            href = url.scheme() + QStringLiteral("://") + url.host() + href;
+        }
+
+        return startXMLDownload(QUrl(href));
+    }
+
     QString OpenSearchDownloadJob::htmlParam(const QString& param, const QString& content)
     {
         QRegExp rx(QString::fromLatin1("%1=\"?([^\">< ]*)[\" ]").arg(param), Qt::CaseInsensitive);
