@@ -17,11 +17,13 @@
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
-#include <klocalizedstring.h>
+
+#include <QComboBox>
+#include <KLocalizedString>
+
 #include "shutdowntorrentmodel.h"
 #include <torrent/queuemanager.h>
 #include <interfaces/coreinterface.h>
-#include <QComboBox>
 
 namespace kt
 {
