@@ -18,6 +18,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTDISPLAYSETTINGSPAGE_H
 #define KTDISPLAYSETTINGSPAGE_H
 
@@ -35,9 +36,7 @@ namespace kt
     {
     public:
         DisplaySettingsPage(QWidget* parent);
-        virtual ~DisplaySettingsPage();
-
-
+        ~DisplaySettingsPage();
     };
 
 }
