@@ -18,12 +18,14 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
+#include <QTextCodec>
+
 #include <util/log.h>
 #include <util/sha1hash.h>
 #include <bcodec/bencoder.h>
 #include <bcodec/bnode.h>
 #include "filter.h"
-#include <qtextcodec.h>
 
 using namespace bt;
 
@@ -35,7 +37,7 @@ namespace kt
         qsrand(time(0));
         for (int i = 0; i < 20; i++)
             data[i] = qrand();
-        return QString("filter:%1").arg(SHA1Hash::generate(data, 20).toString());
+        return QStringLiteral("filter:%1").arg(SHA1Hash::generate(data, 20).toString());
     }
 
     Filter::Filter()
@@ -78,10 +80,10 @@ namespace kt
     bool Filter::getSeasonAndEpisode(const QString& title, int& season, int& episode)
     {
         QStringList se_formats;
-        se_formats << "(\\d+)x(\\d+)"
-                   << "S(\\d+)E(\\d+)"
-                   << "(\\d+)\\.(\\d+)"
-                   << "S(\\d+)\\.E(\\d+)";
+        se_formats << QStringLiteral("(\\d+)x(\\d+)")
+                   << QStringLiteral("S(\\d+)E(\\d+)")
+                   << QStringLiteral("(\\d+)\\.(\\d+)")
+                   << QStringLiteral("S(\\d+)\\.E(\\d+)");
 
         foreach (const QString& format, se_formats)
         {
@@ -230,10 +232,10 @@ namespace kt
     bool Filter::stringToRange(const QString& s, Range& r)
     {
         QString tmp = s.trimmed(); // Get rid of whitespace
-        if (tmp.contains("-"))
+        if (tmp.contains(QLatin1Char('-')))
         {
             // It's a range
-            QStringList parts = s.split("-");
+            QStringList parts = s.split(QStringLiteral("-"));
             if (parts.count() != 2)
                 return false;
 
@@ -267,8 +269,8 @@ namespace kt
     bool Filter::parseNumbersString(const QString& s, QList<Range> & numbers)
     {
         QList<Range> results;
-        QStringList parts = s.split(",");
-        foreach (const QString& p, parts)
+        const QStringList parts = s.split(QStringLiteral(","));
+        for (const QString& p : parts)
         {
             Range r = {0, 0};
             if (stringToRange(p, r))
@@ -311,37 +313,37 @@ namespace kt
     void Filter::save(bt::BEncoder& enc)
     {
         enc.beginDict();
-        enc.write("id", id);
-        enc.write("name", name);
-        enc.write("case_sensitive", case_sensitive);
-        enc.write("all_word_matches_must_match", all_word_matches_must_match);
-        enc.write("exclusion_case_sensitive", exclusion_case_sensitive);
-        enc.write("exclusion_all_must_match", exclusion_all_must_match);
-        enc.write("word_matches");
+        enc.write(QByteArrayLiteral("id"), id.toUtf8());
+        enc.write(QByteArrayLiteral("name"), name.toUtf8());
+        enc.write(QByteArrayLiteral("case_sensitive"), case_sensitive);
+        enc.write(QByteArrayLiteral("all_word_matches_must_match"), all_word_matches_must_match);
+        enc.write(QByteArrayLiteral("exclusion_case_sensitive"), exclusion_case_sensitive);
+        enc.write(QByteArrayLiteral("exclusion_all_must_match"), exclusion_all_must_match);
+        enc.write(QByteArrayLiteral("word_matches"));
         enc.beginList();
         foreach (const QRegExp& exp, word_matches)
-            enc.write(exp.pattern());
+            enc.write(exp.pattern().toUtf8());
         enc.end();
-        enc.write("exclusion_patterns");
+        enc.write(QByteArrayLiteral("exclusion_patterns"));
         enc.beginList();
         foreach (const QRegExp& exp, exclusion_patterns)
-            enc.write(exp.pattern());
+            enc.write(exp.pattern().toUtf8());
         enc.end();
-        enc.write("use_season_and_episode_matching", use_season_and_episode_matching);
-        enc.write("no_duplicate_se_matches", no_duplicate_se_matches);
-        enc.write("seasons", seasons_string);
-        enc.write("episodes", episodes_string);
-        enc.write("download_matching", download_matching);
-        enc.write("download_non_matching", download_non_matching);
+        enc.write(QByteArrayLiteral("use_season_and_episode_matching"), use_season_and_episode_matching);
+        enc.write(QByteArrayLiteral("no_duplicate_se_matches"), no_duplicate_se_matches);
+        enc.write(QByteArrayLiteral("seasons"), seasons_string.toUtf8());
+        enc.write(QByteArrayLiteral("episodes"), episodes_string.toUtf8());
+        enc.write(QByteArrayLiteral("download_matching"), download_matching);
+        enc.write(QByteArrayLiteral("download_non_matching"), download_non_matching);
         if (!dest_group.isEmpty())
-            enc.write("group", dest_group);
+            enc.write(QByteArrayLiteral("group"), dest_group.toUtf8());
         if (!download_location.isEmpty())
-            enc.write("download_location", download_location);
+            enc.write(QByteArrayLiteral("download_location"), download_location.toUtf8());
         if (!move_on_completion_location.isEmpty())
-            enc.write("move_on_completion_location", move_on_completion_location);
-        enc.write("silently", silent);
-        enc.write("use_regular_expressions", use_regular_expressions);
-        enc.write("exclusion_reg_exp", exclusion_reg_exp);
+            enc.write(QByteArrayLiteral("move_on_completion_location"), move_on_completion_location.toUtf8());
+        enc.write(QByteArrayLiteral("silently"), silent);
+        enc.write(QByteArrayLiteral("use_regular_expressions"), use_regular_expressions);
+        enc.write(QByteArrayLiteral("exclusion_reg_exp"), exclusion_reg_exp);
         enc.end();
     }
 
